@@ -311,9 +311,11 @@ gcm_calib_set_extra_metadata (GcmCalibratePriv *calib,
 			       CD_PROFILE_METADATA_DATA_SOURCE,
 			       CD_PROFILE_METADATA_DATA_SOURCE_CALIB);
 	sensor = gcm_calibrate_get_sensor (calib->calibrate);
-	_cmsDictAddEntryAscii (dict,
-			       CD_PROFILE_METADATA_MEASUREMENT_DEVICE,
-			       cd_sensor_kind_to_string (cd_sensor_get_kind (sensor)));
+	if (sensor != NULL) {
+		_cmsDictAddEntryAscii (dict,
+				       CD_PROFILE_METADATA_MEASUREMENT_DEVICE,
+				       cd_sensor_kind_to_string (cd_sensor_get_kind (sensor)));
+	}
 	_cmsDictAddEntryAscii (dict,
 			       CD_PROFILE_METADATA_MAPPING_DEVICE_ID,
 			       cd_device_get_id (calib->device));
@@ -354,6 +356,76 @@ out:
 	return ret;
 }
 
+#if CD_CHECK_VERSION(0,1,20)
+/**
+ * gcm_calib_set_sensor_options_cb:
+ **/
+static void
+gcm_calib_set_sensor_options_cb (GObject *object,
+				 GAsyncResult *res,
+				 gpointer user_data)
+{
+	CdSensor *sensor = CD_SENSOR (object);
+	gboolean ret;
+	GError *error = NULL;
+
+	/* get return value */
+	ret = cd_sensor_set_options_finish (sensor, res, &error);
+	if (!ret) {
+		g_warning ("Failed to set sensor option: %s",
+			   error->message);
+		g_error_free (error);
+	}
+}
+#endif
+
+static void
+gcm_calib_set_sensor_options (GcmCalibratePriv *calib,
+			      const gchar *filename)
+{
+#if CD_CHECK_VERSION(0,1,20)
+	CdSensor *sensor;
+	gboolean ret;
+	gchar *data = NULL;
+	gchar *sha1 = NULL;
+	GError *error = NULL;
+	GHashTable *hash = NULL;
+	gsize len;
+
+	/* get ChSensor */
+	sensor = gcm_calibrate_get_sensor (calib->calibrate);
+	if (sensor == NULL)
+		goto out;
+
+	/* set the remote profile hash */
+	hash = g_hash_table_new_full (g_str_hash,
+				      g_str_equal,
+				      g_free,
+				      (GDestroyNotify) g_variant_unref);
+	ret = g_file_get_contents (filename, &data, &len, &error);
+	if (!ret) {
+		g_warning ("Failed to get SHA1 hash: %s",
+			   error->message);
+		g_error_free (error);
+		goto out;
+	}
+	sha1 = g_compute_checksum_for_data (G_CHECKSUM_SHA1,
+					    (const guchar *) data,
+					    len);
+	g_hash_table_insert (hash,
+			     g_strdup ("remote-profile-hash"),
+			     g_variant_ref_sink (g_variant_new_string (sha1)));
+	cd_sensor_set_options (sensor, hash, NULL,
+			       gcm_calib_set_sensor_options_cb,
+			       calib);
+out:
+	g_free (data);
+	g_free (sha1);
+	if (hash != NULL)
+		g_hash_table_unref (hash);
+#endif
+}
+
 static gboolean
 gcm_calib_start_idle_cb (gpointer user_data)
 {
@@ -408,6 +480,9 @@ gcm_calib_start_idle_cb (gpointer user_data)
 		goto out;
 	}
 
+	/* inform the sensor about the last successful profile */
+	gcm_calib_set_sensor_options (calib, filename);
+
 	/* copy the ICC file to the proper location */
 	file = g_file_new_for_path (filename);
 	profile = cd_client_import_profile_sync (calib->client,
@@ -480,54 +555,6 @@ gcm_calib_assistant_page_forward_cb (gint current_page, gpointer user_data)
 	return current_page;
 }
 
-/**
- * gcm_calibrate_show_profile_location:
- **/
-static void
-gcm_calibrate_show_profile_location (void)
-{
-	gboolean ret;
-	gchar *command_line;
-	GError *error = NULL;
-
-	/* just hardcode nautilus to open the folder */
-	command_line = g_strdup_printf ("nautilus %s/%s",
-					g_get_user_data_dir (),
-					"icc");
-	ret = g_spawn_command_line_async (command_line, &error);
-	if (!ret) {
-		g_warning ("failed to show profile: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-out:
-	g_free (command_line);
-}
-
-/**
- * gcm_calibrate_is_livecd:
- **/
-static gboolean
-gcm_calibrate_is_livecd (void)
-{
-	gboolean ret;
-	gchar *data = NULL;
-	GError *error = NULL;
-
-	/* get the kernel commandline */
-	ret = g_file_get_contents ("/proc/cmdline", &data, NULL, &error);
-	if (!ret) {
-		g_warning ("failed to get kernel command line: %s",
-			   error->message);
-		g_error_free (error);
-		goto out;
-	}
-	ret = g_strstr_len (data, -1, "liveimg") != NULL;
-out:
-	g_free (data);
-	return ret;
-}
-
 /**
  * gcm_calib_assistant_prepare_cb:
  **/
@@ -536,17 +563,11 @@ gcm_calib_assistant_prepare_cb (GtkAssistant *assistant,
 				GtkWidget *page_widget,
 				GcmCalibratePriv *calib)
 {
-	gboolean ret;
 	calib->current_page = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (page_widget),
 								   "GcmCalibrateMain::Index"));
 	switch (calib->current_page) {
 	case GCM_CALIBRATE_PAGE_LAST:
 		gcm_calib_play_sound (calib);
-
-		/* show the user the profile to copy off the live system */
-		ret = gcm_calibrate_is_livecd ();
-		if (ret)
-			gcm_calibrate_show_profile_location ();
 		break;
 	case GCM_CALIBRATE_PAGE_ACTION:
 		g_debug ("lights! camera! action!");
@@ -732,12 +753,98 @@ gcm_calib_setup_page_intro (GcmCalibratePriv *calib)
 	gtk_widget_show_all (vbox);
 }
 
+/**
+ * gcm_calibrate_is_livecd:
+ **/
+static gboolean
+gcm_calibrate_is_livecd (void)
+{
+	gboolean ret;
+	gchar *data = NULL;
+	GError *error = NULL;
+
+	/* get the kernel commandline */
+	ret = g_file_get_contents ("/proc/cmdline", &data, NULL, &error);
+	if (!ret) {
+		g_warning ("failed to get kernel command line: %s",
+			   error->message);
+		g_error_free (error);
+		goto out;
+	}
+	ret = g_strstr_len (data, -1, "liveimg") != NULL;
+out:
+	g_free (data);
+	return ret;
+}
+
+/**
+ * gcm_calib_show_profile_button_clicked_cb:
+ **/
+static void
+gcm_calib_show_profile_button_clicked_cb (GtkButton *button,
+					  GcmCalibratePriv *calib)
+{
+	gboolean ret;
+	gchar *command_line;
+	GError *error = NULL;
+
+	/* just hardcode nautilus to open the folder */
+	command_line = g_strdup_printf ("nautilus %s/%s",
+					g_get_user_data_dir (),
+					"icc");
+	ret = g_spawn_command_line_async (command_line, &error);
+	if (!ret) {
+		g_warning ("failed to show profile: %s", error->message);
+		g_error_free (error);
+		goto out;
+	}
+out:
+	g_free (command_line);
+}
+
+/**
+ * gcm_calib_get_show_profile_button:
+ **/
+static GtkWidget *
+gcm_calib_get_show_profile_button (GcmCalibratePriv *calib)
+{
+	GtkStyleContext *context;
+	GtkWidget *button;
+	GtkWidget *image;
+	GtkWidget *label;
+	GtkWidget *vbox;
+
+	/* add button to show profile */
+	button = gtk_button_new ();
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+	image = gtk_image_new_from_icon_name ("folder-publicshare-symbolic",
+					      GTK_ICON_SIZE_DIALOG);
+
+	/* make image have a gray foreground */
+	context = gtk_widget_get_style_context (image);
+	gtk_style_context_add_class (context, GTK_STYLE_CLASS_IMAGE);
+
+	gtk_box_pack_start (GTK_BOX (vbox), image, FALSE, FALSE, 0);
+	label = gtk_label_new (_("Show File"));
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (button), vbox);
+	gtk_widget_set_tooltip_text (button, _("Click here to show the profile"));
+	g_signal_connect (button, "clicked",
+			  G_CALLBACK (gcm_calib_show_profile_button_clicked_cb),
+			  calib);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 15);
+	gtk_widget_set_halign (button, GTK_ALIGN_CENTER);
+	gtk_widget_show_all (button);
+	return button;
+}
+
 /**
  * gcm_calib_setup_page_summary:
  **/
 static void
 gcm_calib_setup_page_summary (GcmCalibratePriv *calib)
 {
+	gboolean ret;
 	GtkWidget *vbox;
 	GtkWidget *content;
 	GtkWidget *image;
@@ -759,12 +866,10 @@ gcm_calib_setup_page_summary (GcmCalibratePriv *calib)
 	case CD_DEVICE_KIND_DISPLAY:
 		/* TRANSLATORS: this is the final summary */
 		gcm_calib_add_page_para (content, _("The display has been calibrated successfully."));
-		gcm_calib_add_page_para (content, _("You may notice the screen is a slightly different color."));
 		break;
 	case CD_DEVICE_KIND_PRINTER:
 		/* TRANSLATORS: this is the final summary */
 		gcm_calib_add_page_para (content, _("The printer has been calibrated successfully."));
-		gcm_calib_add_page_para (content, _("Documents printed from this device will be color managed."));
 		break;
 	default:
 		/* TRANSLATORS: this is the final summary */
@@ -777,10 +882,20 @@ gcm_calib_setup_page_summary (GcmCalibratePriv *calib)
 		/* TRANSLATORS: this is the final summary */
 		gcm_calib_add_page_para (content, _("To view details about the new profile or to undo the calibration visit the <a href=\"control-center://color\">control center</a>."));
 	}
-	/* add image for success */
-	image = gtk_image_new ();
-	gtk_image_set_from_icon_name (GTK_IMAGE (image), "face-smile", GTK_ICON_SIZE_DIALOG);
-	gtk_box_pack_start (GTK_BOX (vbox), image, FALSE, FALSE, 0);
+
+	/* show the user the profile to copy off the live system */
+	ret = gcm_calibrate_is_livecd ();
+	if (ret) {
+		/* show button to copy profile */
+		image = gcm_calib_get_show_profile_button (calib);
+		gtk_box_pack_start (GTK_BOX (content), image, FALSE, FALSE, 30);
+		gcm_calib_add_page_para (content, _("You can use the profile with <a href=\"import-linux\">Linux</a>, <a href=\"import-osx\">Apple OS X</a> and <a href=\"import-windows\">Microsoft Windows</a> systems."));
+	} else {
+		/* add image for success */
+		image = gtk_image_new ();
+		gtk_image_set_from_icon_name (GTK_IMAGE (image), "face-smile", GTK_ICON_SIZE_DIALOG);
+		gtk_box_pack_start (GTK_BOX (content), image, FALSE, FALSE, 0);
+	}
 
 	/* add to assistant */
 	gtk_assistant_append_page (assistant, vbox);
