@@ -24,7 +24,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <math.h>
-#include <colord.h>
+#include <colord-gtk.h>
 #include <lcms2.h>
 #include <canberra-gtk.h>
 
@@ -35,7 +35,6 @@
 #include "gcm-utils.h"
 #include "gcm-brightness.h"
 #include "gcm-exif.h"
-#include "gcm-sample-window.h"
 
 static void     gcm_calibrate_finalize	(GObject     *object);
 
@@ -652,8 +651,8 @@ gcm_calibrate_get_samples (GcmCalibrate *calibrate,
 
 	/* setup the measure window */
 	cd_color_set_rgb (&rgb_tmp, 1.0f, 1.0f, 1.0f);
-	gcm_sample_window_set_color (GCM_SAMPLE_WINDOW (priv->sample_window), &rgb_tmp);
-	gcm_sample_window_set_percentage (GCM_SAMPLE_WINDOW (priv->sample_window), 0);
+	cd_sample_window_set_color (CD_SAMPLE_WINDOW (priv->sample_window), &rgb_tmp);
+	cd_sample_window_set_fraction (CD_SAMPLE_WINDOW (priv->sample_window), 0.0f);
 	gtk_window_set_modal (priv->sample_window, TRUE);
 	gtk_window_stick (priv->sample_window);
 	gtk_window_present (priv->sample_window);
@@ -676,9 +675,9 @@ gcm_calibrate_get_samples (GcmCalibrate *calibrate,
 			 rgb->R, rgb->G, rgb->B);
 
 		/* set the window color */
-		gcm_sample_window_set_color (GCM_SAMPLE_WINDOW (priv->sample_window), rgb);
-		gcm_sample_window_set_percentage (GCM_SAMPLE_WINDOW (priv->sample_window),
-						  100 * i / samples_rgb->len);
+		cd_sample_window_set_color (CD_SAMPLE_WINDOW (priv->sample_window), rgb);
+		cd_sample_window_set_fraction (CD_SAMPLE_WINDOW (priv->sample_window),
+					       i / samples_rgb->len);
 
 		/* wait for the refresh to set the new color */
 		if (i == 0 && !priv->sensor_on_screen) {
@@ -1744,6 +1743,8 @@ gcm_calibrate_camera_get_reference_data (const gchar *directory, GtkWindow *wind
 	gtk_file_filter_add_mime_type (filter, "application/x-it87");
 
 	/* we can remove this when we depend on a new shared-mime-info */
+	gtk_file_filter_add_pattern (filter, "*.cie");
+	gtk_file_filter_add_pattern (filter, "*.CIE");
 	gtk_file_filter_add_pattern (filter, "*.txt");
 	gtk_file_filter_add_pattern (filter, "*.TXT");
 	gtk_file_filter_add_pattern (filter, "*.it8");
@@ -1945,6 +1946,21 @@ gcm_calibrate_get_enabled (GcmCalibrate *calibrate)
 	return TRUE;
 }
 
+/**
+ * gcm_calibrate_get_reference_cie:
+ **/
+static const gchar *
+gcm_calibrate_get_reference_cie (GcmCalibrateReferenceKind kind)
+{
+	if (kind == GCM_CALIBRATE_REFERENCE_KIND_CMP_DIGITAL_TARGET_3)
+		return "CMP_Digital_Target-3.cie";
+	if (kind == GCM_CALIBRATE_REFERENCE_KIND_COLOR_CHECKER)
+		return "ColorChecker.cie";
+	if (kind == GCM_CALIBRATE_REFERENCE_KIND_QPCARD_201)
+		return "QPcard_201.cie";
+	return NULL;
+}
+
 /**
  * gcm_calibrate_camera:
  **/
@@ -1957,6 +1973,7 @@ gcm_calibrate_camera (GcmCalibrate *calibrate, CdDevice *device, GtkWindow *wind
 	gchar *reference_data = NULL;
 	gchar *device_str = NULL;
 	const gchar *directory;
+	const gchar *tmp;
 	GString *string;
 	GtkWindow *window_tmp = NULL;
 	gchar *precision = NULL;
@@ -1983,15 +2000,25 @@ gcm_calibrate_camera (GcmCalibrate *calibrate, CdDevice *device, GtkWindow *wind
 		g_debug ("no EXIF data, so using device attributes");
 
 	/* get reference data */
-	directory = has_shared_targets ? "/usr/share/color/targets" : "/media";
-	reference_data = gcm_calibrate_camera_get_reference_data (directory, window_tmp);
-	if (reference_data == NULL) {
-		g_set_error_literal (error,
-				     GCM_CALIBRATE_ERROR,
-				     GCM_CALIBRATE_ERROR_USER_ABORT,
-				     "could not get reference target");
-		ret = FALSE;
-		goto out;
+	tmp = gcm_calibrate_get_reference_cie (priv->reference_kind);
+	if (tmp != NULL) {
+		/* some references don't have custom CIE files available
+		 * to them and instead rely on a fixed reference */
+		reference_data = g_build_filename ("/usr/share/color/argyll/ref",
+						   tmp,
+						   NULL);
+	} else {
+		/* ask the user to find the profile */
+		directory = has_shared_targets ? "/usr/share/color/targets" : "/media";
+		reference_data = gcm_calibrate_camera_get_reference_data (directory, window_tmp);
+		if (reference_data == NULL) {
+			g_set_error_literal (error,
+					     GCM_CALIBRATE_ERROR,
+					     GCM_CALIBRATE_ERROR_USER_ABORT,
+					     "could not get reference target");
+			ret = FALSE;
+			goto out;
+		}
 	}
 
 	/* use the ORIGINATOR in the it8 file */
@@ -2458,7 +2485,7 @@ gcm_calibrate_init (GcmCalibrate *calibrate)
 	calibrate->priv->print_kind = GCM_CALIBRATE_PRINT_KIND_UNKNOWN;
 	calibrate->priv->reference_kind = GCM_CALIBRATE_REFERENCE_KIND_UNKNOWN;
 	calibrate->priv->precision = GCM_CALIBRATE_PRECISION_UNKNOWN;
-	calibrate->priv->sample_window = gcm_sample_window_new ();
+	calibrate->priv->sample_window = cd_sample_window_new ();
 	calibrate->priv->old_brightness = G_MAXUINT;
 	calibrate->priv->brightness = gcm_brightness_new ();
 
